/* Nord color scheme by Arctic Ice Studio: https://www.nordtheme.com/ */

/* Font and Radius Variables */
:root {
    --monospace-font: var(--marimo-monospace-font, "Fira Mono", monospace);
    --text-font: var(--marimo-text-font, "PT Sans", sans-serif);
    --heading-font: var(--marimo-heading-font, "Lora", serif);
    --radius: 8px;
}

/* Nord color palette */
:root {
    /* Polar Night (dark) */
    --nord0: hsl(220, 16%, 22%); /* dark bg */
    --nord1: hsl(222, 16%, 28%); /* dark bg highlights */
    --nord2: hsl(220, 17%, 32%); /* dark content */
    --nord3: hsl(220, 16%, 36%); /* dark content */

    /* Snow Storm (light) */
    --nord4: hsl(219, 28%, 88%); /* light content */
    --nord5: hsl(218, 27%, 92%); /* light content */
    --nord6: hsl(218, 27%, 94%); /* light bg highlights */

    /* Frost (blues) */
    --nord7: hsl(179, 25%, 65%); /* frost mint */
    --nord8: hsl(193, 43%, 67%); /* frost light blue */
    --nord9: hsl(210, 34%, 63%); /* frost blue */
    --nord10: hsl(213, 32%, 52%); /* frost deep blue */

    /* Aurora (accent colors) */
    --nord11: hsl(354, 42%, 56%); /* red */
    --nord12: hsl(14, 51%, 63%); /* orange */
    --nord13: hsl(40, 71%, 73%); /* yellow */
    --nord14: hsl(92, 28%, 65%); /* green */
    --nord15: hsl(311, 20%, 63%); /* purple */
}

/* Base colors with light-dark variants */
:root {
    --background: light-dark(var(--nord6), var(--nord0));
    --foreground: light-dark(var(--nord3), var(--nord4));
    --muted: light-dark(var(--nord5), var(--nord1));
    --muted-foreground: light-dark(var(--nord2), var(--nord5));
    --popover: light-dark(var(--nord6), var(--nord0));
    --popover-foreground: light-dark(var(--nord3), var(--nord4));
    --card: light-dark(var(--nord6), var(--nord0));
    --card-foreground: light-dark(var(--nord3), var(--nord4));
    --border: light-dark(var(--nord4), var(--nord2));
    --input: light-dark(var(--nord4), var(--nord2));
    --primary: light-dark(var(--nord10), var(--nord9));
    --primary-foreground: light-dark(var(--nord6), var(--nord0));
    --secondary: light-dark(var(--nord5), var(--nord2));
    --secondary-foreground: light-dark(var(--nord3), var(--nord0));
    --accent: light-dark(var(--nord8), var(--nord8));
    --accent-foreground: light-dark(var(--nord0), var(--nord6));
    --ring: var(--nord9);
}

/* Semantic colors */
:root {
    --destructive: var(--nord11);
    --destructive-foreground: light-dark(var(--nord6), var(--nord0));
    --error: var(--nord11);
    --error-foreground: light-dark(var(--nord6), var(--nord0));
    --success: var(--nord14);
    --success-foreground: light-dark(var(--nord6), var(--nord0));
    --action: var(--nord13);
    --action-hover: light-dark(hsl(40, 71%, 78%), hsl(40, 71%, 68%));
    --action-foreground: light-dark(var(--nord0), var(--nord0));
    --link: light-dark(var(--nord10), var(--nord9));
    --link-visited: light-dark(var(--nord15), var(--nord15));
    --stale: hsl(40, 71% 73% / 25%);
}

/* Base shadows */
:root {
    --base-shadow: light-dark(hsla(218, 27%, 70% / 40%), hsla(220, 16%, 15% / 60%));
    --base-shadow-darker: light-dark(
        hsla(218, 27%, 60% / 40%),
        hsla(220, 16%, 18% / 60%)
    );
    --base-shadow-opacity: 5%;
}

